@@ -28,7 +28,7 @@ class DomainCalculus:
         # select statement
         result_query = ''
         for variable in self.result.variables:
-            result_query += f'{variable.name}, '
+            result_query += f'"{variable.name}", '
         result_query = result_query[:-len(', ')]  # remove last ', '
 
         formula = self.to_normal_form().formula
@@ -47,14 +47,17 @@ class DomainCalculus:
         union_formulas = list()
         union_formulas.append(formula)
         while True:
-            tmp = list()
+            new_unions = list()
+            old_unions = list()
             for formula in union_formulas:
                 if isinstance(formula, Or):
-                    tmp.append(formula.children[0])
-                    tmp.append(formula.children[1])
-            if len(tmp) == 0:  # no new updates
+                    new_unions.append(formula.children[0])
+                    new_unions.append(formula.children[1])
+                else:
+                    old_unions.append(formula)
+            if len(new_unions) == 0:  # no new updates
                 break
-            union_formulas = list(tmp)
+            union_formulas = list(new_unions + old_unions)
 
         # AND -> (NATURAL) JOIN
         joins = list()
@@ -83,7 +86,8 @@ class DomainCalculus:
             select_query = f'SELECT DISTINCT {result_query} '
             from_query = ''
             for t in tuples:
-                with_query += f'table_{id}({",".join(list(map(lambda var: var.name, t.variables)))}) AS (SELECT * FROM {t.type}), '
+                __quotation_mark = '"' # cannot use backslash in f''-string
+                with_query += f'table_{id}({",".join(list(map(lambda var: __quotation_mark + var.name + __quotation_mark, t.variables)))}) AS (SELECT * FROM {t.type}), '
                 from_query += f'table_{id} NATURAL JOIN '
                 id += 1
             from_query = from_query[:-len(' NATURAL JOIN ')]
@@ -93,7 +97,7 @@ class DomainCalculus:
                 if len(forall_variables) != 0:
                     sub_query = 'NOT EXISTS '
                     for variable in forall_variables:
-                        sub_query = f'(SELECT {variable.name} FROM {from_query} WHERE EXISTS '
+                        sub_query = f'(SELECT "{variable.name}" FROM {from_query} WHERE EXISTS '
                     sub_query = sub_query[:-len('EXISTS ')]
                     sub_query += f'NOT ({sub_formula.to_sql()})'
                     sub_query += ')' * len(forall_variables)
@@ -405,6 +409,11 @@ class And(Formula):
         if isinstance(self.children[0], Or):  # move Or outward
             return Or(And(self.children[0].children[0], self.children[1]), And(self.children[0].children[1], self.children[1])).to_normal_form()
 
+        if isinstance(self.children[0], And):
+            # move Tuple outward
+            if isinstance(self.children[0].children[0], Tuple):
+                return And(self.children[0].children[0], And(self.children[0].children[1], self.children[1])).to_normal_form()
+
         # for all other cases of self.children[0] check self.children[1] (right side)
         if isinstance(self.children[1], Exists):
             return Exists(self.children[1].variable, And(self.children[0], self.children[1].children[0]).to_normal_form())
@@ -532,3 +541,35 @@ if __name__ == '__main__':
     print(pnf)
     print('')
     print(domain_calculus.to_sql())
+
+
+    print('\n\nDEBUG:\n')
+    GehegeNR = Variable("GehegeNR")
+    AnzahlTiere = Variable("AnzahlTiere")
+    mNR = Variable("mNR")
+    ChipID = Variable("ChipID")
+    Datum = Variable("Datum")
+    vU = Variable("vU")
+    bU = Variable("bU")
+    Name = Variable("Name")
+    Alter = Variable("Alter")
+
+    expression = Exists(mNR, Exists(ChipID, Exists(Datum, Exists(vU, Exists(bU, Exists(Name, Exists(Alter,
+        And(
+            Tuple("zuständig", [mNR, GehegeNR, ChipID, Datum, vU, bU]),
+            And(
+                Tuple("Gehege", [GehegeNR, "5", AnzahlTiere]),
+                Tuple("Tier", [ChipID, Name, "Löwe", Alter])
+            )
+        ))))))))
+
+    ### END SOLUTION
+
+    domainc = DomainCalculus(Result([GehegeNR, AnzahlTiere]), expression)
+    print(domainc)
+    print('')
+    print(domainc.to_normal_form())
+    print('')
+    print(domainc.to_sql())
+    print('')
+    print(domainc.to_normal_form().to_sql())
\ No newline at end of file
